@@ -120,6 +120,7 @@ extern "C" {
 #include <freeipmi/spec/ipmi-system-info-parameters-spec.h>
 #include <freeipmi/spec/ipmi-system-software-id-spec.h>
 #include <freeipmi/spec/oem/ipmi-cmd-oem-dell-spec.h>
+#include <freeipmi/spec/oem/ipmi-cmd-oem-gigabyte-spec.h>
 #include <freeipmi/spec/oem/ipmi-cmd-oem-fujitsu-spec.h>
 #include <freeipmi/spec/oem/ipmi-cmd-oem-ibm-spec.h>
 #include <freeipmi/spec/oem/ipmi-cmd-oem-intel-node-manager-spec.h>
@@ -152,6 +153,7 @@ extern "C" {
 #include <freeipmi/spec/oem/ipmi-netfn-oem-wistron-spec.h>
 #include <freeipmi/spec/oem/ipmi-oem-dell-spec.h>
 #include <freeipmi/spec/oem/ipmi-oem-fujitsu-spec.h>
+#include <freeipmi/spec/oem/ipmi-oem-gigabyte-spec.h>
 #include <freeipmi/spec/oem/ipmi-oem-ibm-spec.h>
 #include <freeipmi/spec/oem/ipmi-oem-intel-spec.h>
 #include <freeipmi/spec/oem/ipmi-oem-inventec-spec.h>
@@ -161,6 +163,7 @@ extern "C" {
 #include <freeipmi/spec/oem/ipmi-oem-wistron-spec.h>
 #include <freeipmi/spec/oem/ipmi-sensor-and-event-code-tables-oem-dell-spec.h>
 #include <freeipmi/spec/oem/ipmi-sensor-and-event-code-tables-oem-fujitsu-spec.h>
+#include <freeipmi/spec/oem/ipmi-sensor-and-event-code-tables-oem-gigabyte-spec.h>
 #include <freeipmi/spec/oem/ipmi-sensor-and-event-code-tables-oem-hp-spec.h>
 #include <freeipmi/spec/oem/ipmi-sensor-and-event-code-tables-oem-intel-node-manager-spec.h>
 #include <freeipmi/spec/oem/ipmi-sensor-and-event-code-tables-oem-intel-spec.h>
@@ -210,10 +213,10 @@ extern "C" {
 #include <freeipmi/util/ipmi-dcmi-util.h>
 #include <freeipmi/util/rmcp-util.h>
 
-#define FREEIPMI_PACKAGE_VERSION       1.5.2
+#define FREEIPMI_PACKAGE_VERSION       1.5.5
 #define FREEIPMI_PACKAGE_VERSION_MAJOR 1
 #define FREEIPMI_PACKAGE_VERSION_MINOR 5
-#define FREEIPMI_PACKAGE_VERSION_PATCH 2
+#define FREEIPMI_PACKAGE_VERSION_PATCH 5
 
 /*
  * Libfreeipmi version
@@ -233,7 +236,7 @@ extern "C" {
 
 #define LIBFREEIPMI_VERSION_MAJOR 6
 #define LIBFREEIPMI_VERSION_MINOR 1
-#define LIBFREEIPMI_VERSION_PATCH 0
+#define LIBFREEIPMI_VERSION_PATCH 3
 
 #ifdef __cplusplus
 }
